using System;
using Server;
using Server.Items;
using Server.Mobiles;
using Server.Gumps;
using Server.Network;

namespace Server.Items
{
	public class ToS : Item
	{
		public bool m_Active;
		public Point3D m_PlayerDest;
		public Point3D m_MonsterDest;
		private Point3D m_OrigLocation;
		private RoundTimer rt;
		private TeamTimer tt;
		public bool m_Doubles;
		private Mobile partner;
		private Mobile dude;

		[CommandProperty(AccessLevel.GameMaster)]
		public bool Active
		{
			get{ return m_Active; }
			set{ m_Active = value; }
		}

		[CommandProperty(AccessLevel.GameMaster)]
		public Point3D PlayerDest
		{
			get{ return m_PlayerDest; }
			set{ m_PlayerDest = value; }
		}

		[CommandProperty(AccessLevel.GameMaster)]
		public Point3D MonsterDest
		{
			get{ return m_MonsterDest; }
			set{ m_MonsterDest = value; }
		}

		[Constructable]
		public ToS() : base( 0xEDC )
		{
			Weight = 10;
			Name = "A ToS Stone";
			Movable = false;
		}

		public override void OnDoubleClick( Mobile from )
		{
			if(Active)
				from.SendMessage(3, "The ToS Stone is currently in use. Please try later!");

			else if(!Active)
			{
				from.SendGump( new ToSGump(this) );
				Active = true;
			}
		}

		public void EndGameNoWin(Mobile from, Mobile killer)
		{
			killer.Delete();
			from.Resurrect();
			from.Location = m_OrigLocation;
			from.SendMessage( 3, "You have lost ToS. Better luck next time!");
			Active = false;
		}

		public void EndGameNoWinDouble( Mobile from, Mobile who, Mobile killer)
		{
			if(killer is BaseCreature)
			{
				killer.Delete();
			}

			m_Doubles = false;
			from.Resurrect();
			who.Resurrect();
			from.Location = m_OrigLocation;
			who.Location = m_OrigLocation;
			from.SendMessage( 3, "You have lost ToS. Better luck next time!");
			who.SendMessage( 3, "You have lost ToS. Better luck next time!");
			Active = false;
		}

		public void EndGameWin(Mobile from)
		{
			rt.Stop();
			from.Location = m_OrigLocation;	
			from.SendMessage( 3, "Congratulations, you have won ToS! Your ToS Ticket has been placed inside of your backpack.");
			Active = false;
			Item tos = new ToSTicket();
			from.Backpack.DropItem(tos);
		}

		public void EndGameWinDouble()
		{
			tt.Stop();
			m_Doubles = false;
			dude.Location = m_OrigLocation;	
			partner.Location = m_OrigLocation;	
			partner.SendMessage( 3, "Congratulations, you have won ToS! However, winning Team ToS does not earn you a ToS Ticket.");
			dude.SendMessage( 3, "Congratulations, you have won ToS! However, winning Team ToS does not earn you a ToS Ticket.");
			Active = false;
		}	

		public void StartToSSingle(Mobile from)
		{
			from.SendMessage( 3, "You have begun ToS");
			Active = true;
			m_OrigLocation = from.Location;
			from.Location = PlayerDest;
			BeginRoundOneSingle(from);
		}

		public void StartToSDouble(Mobile from, Mobile teammate)
		{
			from.SendMessage( 3, "You have begun Team ToS");
			teammate.SendMessage( 3, "You have begun Team ToS");
			Active = true;
			m_Doubles = true;
			partner = teammate;
			dude = from;
			m_OrigLocation = from.Location;
			from.Location = PlayerDest;
			Point3D temp = PlayerDest;
			temp.X += 1;
			teammate.Location = temp;
			BeginRoundOneDouble(from, teammate);
		}

		public void BeginRoundOneSingle(Mobile from)
		{
			Mobile r1 = new Round1Monster(this);
			r1.MoveToWorld(MonsterDest, Map.Felucca);
			PlayerMobile conv = (PlayerMobile)from;
			rt = new RoundTimer(conv, this);
			rt.Start();
		}

		public void BeginRoundOneDouble(Mobile from, Mobile who)
		{
			Mobile r1 = new Round1Monster(this);
			r1.MoveToWorld(MonsterDest, Map.Felucca);
			PlayerMobile conv = (PlayerMobile)from;
			PlayerMobile that = (PlayerMobile)who;
			tt = new TeamTimer( conv, that, this );
			tt.Start();
		}

		public void BeginRoundTwo()
		{
			Mobile r2 = new Round2Monster(this);
			r2.MoveToWorld(MonsterDest, Map.Felucca);
		}

		public void BeginRoundThree()
		{
			Mobile r3 = new Round3Monster(this);
			r3.MoveToWorld(MonsterDest, Map.Felucca);
		}

		public void BeginRoundFour()
		{
			Mobile r4 = new Round4Monster(this);
			r4.MoveToWorld(MonsterDest, Map.Felucca);
		}

		public void BeginRoundFive()
		{
			Mobile r5 = new Round5Monster(this);
			r5.MoveToWorld(MonsterDest, Map.Felucca);
		}

		public void BeginRoundSix()
		{
			Mobile r6 = new Round6Monster(this);
			r6.MoveToWorld(MonsterDest, Map.Felucca);
		}

		public void BeginRoundSeven()
		{
			Mobile r7 = new Round7Monster(this);
			r7.MoveToWorld(MonsterDest, Map.Felucca);
		}

		public void BeginRoundEight()
		{
			Mobile r8 = new Round8Monster(this);
			r8.MoveToWorld(MonsterDest, Map.Felucca);
		}

		public void BeginRoundNine()
		{
			Mobile r9 = new Round9Monster(this);
			r9.MoveToWorld(MonsterDest, Map.Felucca);
		}

		public void BeginRoundTen()
		{
			Mobile r10 = new Round10Monster(this);
			r10.MoveToWorld(MonsterDest, Map.Felucca);
		}

		public ToS( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );

			writer.Write( (int)0 );
			writer.Write( m_Active );
			writer.Write( m_PlayerDest );
			writer.Write( m_MonsterDest );
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );

			int version = reader.ReadInt();

			switch ( version )
			{
				case 0:
				{
					m_Active = reader.ReadBool();
					m_PlayerDest = reader.ReadPoint3D();
					m_MonsterDest = reader.ReadPoint3D();
					break;
				}
			}
		}

		public class RoundTimer : Timer 
		{
			ToS m_Item;
			PlayerMobile who;

			public RoundTimer(PlayerMobile and, ToS game) : base( TimeSpan.FromSeconds( 1.0 ), TimeSpan.FromSeconds( 1.0 ))
			{
				PlayerMobile grant = (PlayerMobile)and;
				who = grant;
				m_Item = game;
			} 

			protected override void OnTick() 
			{
				if(!who.Alive)
				{
					Mobile killer = who.FindMostRecentDamager( true );

					if ( who.Corpse != null && !who.Corpse.Deleted )
						who.Corpse.MoveToWorld(m_Item.m_OrigLocation, Map.Felucca);

					m_Item.EndGameNoWin(who, killer);
					Stop();
				}
			}
		}

		public class TeamTimer : Timer
		{
			ToS m_Item;
			PlayerMobile who;
			PlayerMobile teammate;

			public TeamTimer(PlayerMobile from, PlayerMobile target, ToS game) : base( TimeSpan.FromSeconds(1.0), TimeSpan.FromSeconds(1.0))
			{
				PlayerMobile castit = (PlayerMobile)from;
				PlayerMobile other = (PlayerMobile)target;

				who = from;
				teammate = other;

				m_Item = game;
			}

			protected override void OnTick()
			{
				if(!who.Alive || !teammate.Alive)
				{
					if(!who.Alive)
					{
						Mobile killer = who.FindMostRecentDamager( true );

						if ( who.Corpse != null && !who.Corpse.Deleted )
							who.Corpse.MoveToWorld(m_Item.m_OrigLocation, Map.Felucca);

						m_Item.EndGameNoWinDouble( who, teammate, killer );
						Stop();
					}

					if(!teammate.Alive)
					{
						Mobile killer = teammate.FindMostRecentDamager( true );

						if ( teammate.Corpse != null && !teammate.Corpse.Deleted )
							teammate.Corpse.MoveToWorld(m_Item.m_OrigLocation, Map.Felucca);

						m_Item.EndGameNoWinDouble( who, teammate, killer );
						Stop();
					}
				}
			}
		}
	}
}